@@ -51,4 +51,4 @@ LSF$template = paste(sep="\n",
     "#BSUB-R rusage[mem={{ memory | 4096  }}]  # Memory requirements in Mbytes",
     "",
     "ulimit -v $(( 1024 * {{ memory | 4096 }} ))",
-    "R --no-save --no-restore -e 'clustermq:::worker(\"{{ master }}\"')")
+    "R --no-save --no-restore -e 'clustermq:::worker(\"{{ master }}\")'")
